Fuzzy image processing tutorials {#tutorial_fuzzy}
=============================================================

-   @subpage tutorial_fuzzy_theory

    _Compatibility:_ \> OpenCV 3.2.0

    _Author:_ Pavel Vlasanek

    You will learn basics about fuzzy mathematics namely F-transform of certain degree.

-   @subpage tutorial_fuzzy_inpainting

    _Compatibility:_ \> OpenCV 3.2.0

    _Author:_ Pavel Vlasanek

    You will learn how to use fuzzy mathematics in task of image inpainting.

-	@subpage tutorial_fuzzy_filtering

	_Compatibility:_ \> OpenCV 3.2.0

	_Author:_ Pavel Vlasanek

    You will learn how to use fuzzy mathematics in task of image filtering.